var servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLink =
[
    [ "com::sun::star::beans::XPropertySet", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLink.html#ae6872c0d73362de7c3f167030e03e1cf", null ],
    [ "com::sun::star::sheet::XAreaLink", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLink.html#a8ede2e513a569c1da645774998a751c3", null ],
    [ "com::sun::star::util::XRefreshable", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLink.html#abad65f33e0c30489f58a423e7ef907aa", null ],
    [ "Filter", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLink.html#a36e60b26868092e2acd03532c3dc0549", null ],
    [ "FilterOptions", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLink.html#af841b998ee42c081965e62af46019fd4", null ],
    [ "RefreshDelay", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLink.html#a6c7eee759d72b5f818b800aacbdf6f5a", null ],
    [ "RefreshPeriod", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLink.html#a84d65c48a2751fa526d687a0257d215e", null ],
    [ "Url", "servicecom_1_1sun_1_1star_1_1sheet_1_1CellAreaLink.html#a9619cd3b7a409d3733877feef572732d", null ]
];